@@ -194,7 +194,7 @@ class CausalTree:
         if self.seed is not None:
             np.random.seed(self.seed)
 
-        if self.honest:
+        if self.honest and not self.val_honest:
             rows, est_rows, labels, est_labels, treatment, est_treatment = \
                 train_test_split(rows, labels, treatment, shuffle=True, test_size=0.5)
 
@@ -1183,6 +1183,12 @@ class CausalTree:
 
         return sorted_vars
 
+    def save_pickle(self, filename):
+        import pickle as pkl
+
+        with open(filename, "wb") as file:
+            pkl.dump(self, file)
+
 
 def grid_search(features, labels, treatment, weights=None, split_sizes=None, cont=None, opt_obj="obj", base_obj=True,
                 weight_obj=False, verbose=True):
